@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 from .audio import AudioControl, STATUS
-from .channel import ChannelType, ChannelSubType, PatchChannelRequest
+from .channel import Channel, ChannelType, ChannelSubType, PatchChannelRequest
 from .channel import CreateChannelRequest
 from .channel_permissions import UpdatePermission
-from .guild_member import QueryParams
+from .guild import Guild
+from .guild_member import GuildMember, QueryParams
 from .guild_role import RoleUpdateInfo
 from .message import CreateDirectMessageRequest, MessageSendRequest, Message
 from .mute import MuteOption
